@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@
  #endif
 #endif
 
+#define SUPPORT_OLD_FORMAT
+
 
 RetrieveYoutubeUrl::RetrieveYoutubeUrl(QObject* parent)
 	: QObject(parent)
@@ -51,9 +53,9 @@ RetrieveYoutubeUrl::RetrieveYoutubeUrl(QObject* parent)
 #endif
 	, preferred_resolution(R720p)
 	, use_https_main(false)
-	, use_https_vi(false)
 #ifdef YT_DASH_SUPPORT
 	, use_dash(false)
+	, use_60fps(false)
 #endif
 {
 	clearData();
@@ -215,9 +217,8 @@ void RetrieveYoutubeUrl::receivedResponse303(QString url) {
 void RetrieveYoutubeUrl::fetchVideoInfoPage(const QString & url) {
 	QString video_id = getVideoID(url);
 
-	QString scheme = use_https_vi ? "https" : "http";
-	QString u = QString("%2://www.youtube.com/get_video_info?video_id=%1&disable_polymer=true&eurl=https://youtube.googleapis.com/v/%1&gl=US&hl=en").arg(video_id).arg(scheme);
-	qDebug() << "RetrieveYoutubeUrl::fetchVideoInfoPage: url:" << url;
+	QString u = QString("https://www.youtube.com/get_video_info?video_id=%1&disable_polymer=true&eurl=https://youtube.googleapis.com/v/%1&gl=US&hl=en").arg(video_id);
+	qDebug() << "RetrieveYoutubeUrl::fetchVideoInfoPage: url:" << u;
 
 	if (u.toLower().startsWith("https") && !QSslSocket::supportsSsl()) {
 		qDebug() << "RetrieveYoutubeUrl::fetchVideoInfoPage: no support for ssl";
@@ -333,9 +334,22 @@ void RetrieveYoutubeUrl::processVideoPage() {
 			return;
 		}
 	}
+
+	QRegExp manifest_rx("\\\\\"hlsManifestUrl\\\\\":\\\\\"(.*)\\\\\"");
+	manifest_rx.setMinimal(true);
+	if (manifest_rx.indexIn(replyString) != -1) {
+		QString manifest_url = QUrl::fromPercentEncoding(manifest_rx.cap(1).toLatin1()).replace("\\/", "/");
+		qDebug() << "RetrieveYoutubeUrl::processVideoPage:" << manifest_url;
+
+		if (!manifest_url.isEmpty()) {
+			fetchStreamPage(manifest_url);
+			return;
+		}
+	}
 #endif
 
 	QString fmtArray;
+#ifdef SUPPORT_OLD_FORMAT
 	QRegExp regex("\\\"url_encoded_fmt_stream_map\\\"\\s*:\\s*\\\"([^\\\"]*)");
 	if (regex.indexIn(replyString) != -1) {
 		fmtArray = regex.cap(1);
@@ -348,6 +362,9 @@ void RetrieveYoutubeUrl::processVideoPage() {
 		fmtArray += regex2.cap(1);
 	}
 	#endif
+#endif
+
+	if (fmtArray.isEmpty()) fmtArray = getArrayFromStreamingData(replyString);
 
 	fmtArray = sanitizeForUnicodePoint(fmtArray);
 	fmtArray.replace(QRegExp("\\\\(.)"), "\\1");
@@ -372,10 +389,58 @@ void RetrieveYoutubeUrl::processVideoPage() {
 	#endif
 }
 
+QString RetrieveYoutubeUrl::getArrayFromStreamingData(const QString & page) {
+	qDebug("RetrieveYoutubeUrl::getArrayFromStreamingData");
+
+	QString fmtArray;
+
+	QStringList exps;
+	exps << "streamingData.*formats\\\\\":\\[(.*)\\]";
+	#ifdef YT_DASH_SUPPORT
+	exps << "streamingData.*adaptiveFormats\\\\\":\\[(.*)\\]";
+	#endif
+
+	foreach(QString expression, exps) {
+		QString text;
+		QRegExp rx_block(expression);
+		rx_block.setMinimal(true);
+		if (rx_block.indexIn(page) != -1) {
+			text = rx_block.cap(1);
+			//qDebug() << "text:" << text;
+
+			QRegExp regex("(cipher|url)\\\\\":\\\\\"(.*)\\\\\"");
+			regex.setMinimal(true);
+
+			int pos = 0;
+			while ((pos = regex.indexIn(text, pos)) != -1) {
+				if (!fmtArray.isEmpty()) fmtArray += ",";
+				if (regex.cap(1) == "url") {
+					QString url = regex.cap(2);
+					url = QUrl::fromPercentEncoding(url.toUtf8());
+					url = sanitizeForUnicodePoint(url);
+					url.replace(QRegExp("\\\\(.)"), "\\1");
+					url = QUrl::toPercentEncoding(url);
+					fmtArray += "url=";
+					fmtArray += url;
+				} else {
+					fmtArray += regex.cap(2);
+				}
+				pos += regex.matchedLength();
+			}
+		}
+	}
+
+	//qDebug() << "RetrieveYoutubeUrl::getArrayFromStreamingData: fmtArray:" << fmtArray;
+	return fmtArray;
+}
+
 #ifdef YT_GET_VIDEOINFO
 void RetrieveYoutubeUrl::videoInfoPageLoaded(QByteArray page) {
 	qDebug() << "RetrieveYoutubeUrl::videoInfoPageLoaded";
 
+	QByteArray fmtArray;
+
+#ifdef SUPPORT_OLD_FORMAT
 	#if QT_VERSION >= 0x050000
 	QUrlQuery all;
 	all.setQuery(page);
@@ -384,7 +449,6 @@ void RetrieveYoutubeUrl::videoInfoPageLoaded(QByteArray page) {
 	all.setEncodedQuery(page);
 	#endif
 
-	QByteArray fmtArray;
 	#if QT_VERSION >= 0x050000
 	fmtArray = all.queryItemValue("url_encoded_fmt_stream_map", QUrl::FullyDecoded).toLatin1();
 	#else
@@ -399,6 +463,14 @@ void RetrieveYoutubeUrl::videoInfoPageLoaded(QByteArray page) {
 	fmtArray += all.queryItemValue("adaptive_fmts").toLatin1();
 	#endif
 #endif
+#endif
+
+	if (fmtArray.isEmpty()) {
+		QString s = QUrl::fromPercentEncoding(page);
+		s = sanitizeForUnicodePoint(s);
+		s.replace("\"", "\\\"");
+		fmtArray = getArrayFromStreamingData(s).toLatin1();
+	}
 
 	//qDebug() <<"RetrieveYoutubeUrl::videoInfoPageLoaded: fmtArray:" << fmtArray;
 
@@ -519,7 +591,7 @@ void RetrieveYoutubeUrl::finish(const UrlMap & url_map) {
 	setUrlMap(url_map);
 
 	#ifdef YT_DASH_SUPPORT
-	selected_quality = findPreferredResolution(url_map, preferred_resolution, use_dash);
+	selected_quality = findPreferredResolution(url_map, preferred_resolution, use_dash, use_60fps);
 	#else
 	selected_quality = findPreferredResolution(url_map, preferred_resolution);
 	#endif
@@ -563,6 +635,20 @@ QString RetrieveYoutubeUrl::aclara(const QString & text, const QString & player)
 }
 #endif
 
+OptMap RetrieveYoutubeUrl::extractOptions(const QByteArray & urldata) {
+	OptMap data;
+	QList<QByteArray> l = urldata.split('&');
+	foreach(QByteArray o, l) {
+		QList<QByteArray> p = o.split('=');
+		if (p.count() > 1) {
+			QString tag = QUrl::fromPercentEncoding(p[0]);
+			QString value = QUrl::fromPercentEncoding(p[1]);
+			data[tag] = value;
+		}
+	}
+	return data;
+}
+
 UrlMap RetrieveYoutubeUrl::extractURLs(QString fmtArray, bool allow_https, bool use_player) {
 	UrlMap url_map;
 
@@ -578,40 +664,37 @@ UrlMap RetrieveYoutubeUrl::extractURLs(QString fmtArray, bool allow_https, bool
 	//qDebug() << "RetrieveYoutubeUrl::extractURLs: codeList.count:" << codeList.count();
 
 	foreach(QByteArray code, codeList) {
-		code = QUrl::fromPercentEncoding(code).toLatin1();
 		//qDebug() << "RetrieveYoutubeUrl::extractURLs: code:" << code;
+		OptMap opt_map = extractOptions(code);
+		//qDebug() << "RetrieveYoutubeUrl::extractURLs: opt_map:" << opt_map;
 
-		QUrl line;
-		#if QT_VERSION >= 0x050000
-		q->setQuery(code);
-		#else
-		QUrl * q = &line;
-		q->setEncodedQuery(code);
-		#endif
+		if (opt_map.contains("url")) {
+			QUrl url(opt_map["url"]);
+			//qDebug() << "RetrieveYoutubeUrl::extractURLs: url:" << url;
 
-		if (q->hasQueryItem("url")) {
-			QUrl url( q->queryItemValue("url") );
-			line.setScheme(url.scheme());
-			line.setHost(url.host());
-			line.setPath(url.path());
-			q->removeQueryItem("url");
 			#if QT_VERSION >= 0x050000
-			q->setQuery( q->query(QUrl::FullyDecoded) + "&" + url.query(QUrl::FullyDecoded) );
+			q->setQuery(url.query(QUrl::FullyDecoded));
 			#else
-			q->setEncodedQuery( q->encodedQuery() + "&" + url.encodedQuery() );
+			QUrl * q = &url;
 			#endif
 
-			if (q->hasQueryItem("sig")) {
-				q->addQueryItem("signature", q->queryItemValue("sig"));
-				q->removeQueryItem("sig");
+			QString signature_name = "signature";
+			if (opt_map.contains("sp")) {
+				signature_name = opt_map["sp"];
+				//qDebug() << "RetrieveYoutubeUrl::extractURLs: signature field:" << signature_name;
+			}
+
+			if (opt_map.contains("sig")) {
+				q->addQueryItem(signature_name, opt_map["sig"]);
 			}
 			else
-			if (q->hasQueryItem("s")) {
+			if (opt_map.contains("s")) {
 				#ifdef YT_USE_SIG
 				QString player = sig.html5_player;
-				QString signature = aclara(q->queryItemValue("s"), use_player ? player : QString::null);
+				QString enc_sig = opt_map["s"];
+				QString signature = aclara(enc_sig, use_player ? player : QString::null);
 				if (!signature.isEmpty()) {
-					q->addQueryItem("signature", signature);
+					q->addQueryItem(signature_name, signature);
 				} else {
 					failed_to_decrypt_signature = true;
 				}
@@ -626,7 +709,19 @@ UrlMap RetrieveYoutubeUrl::extractURLs(QString fmtArray, bool allow_https, bool
 
 			if (!q->hasQueryItem("ratebypass")) q->addQueryItem("ratebypass", "yes");
 
-			if ((q->hasQueryItem("itag")) && (q->hasQueryItem("signature"))) {
+			if (opt_map.contains("clen")) {
+				if (opt_map["clen"] == "0") {
+					qDebug() << "RetrieveYoutubeUrl::extractURLs: discarted url with empty clen";
+					continue;
+				}
+			} else {
+				if (!q->hasQueryItem("clen")) {
+					qDebug() << "RetrieveYoutubeUrl::extractURLs: discarted url with no clen";
+					continue;
+				}
+			}
+
+			if ((q->hasQueryItem("itag")) /*&& (q->hasQueryItem(signature_name))*/) {
 				QString itag = q->queryItemValue("itag");
 
 				// Remove duplicated queries
@@ -637,6 +732,7 @@ UrlMap RetrieveYoutubeUrl::extractURLs(QString fmtArray, bool allow_https, bool
 					q->addQueryItem(item.first, item.second);
 				}
 
+				QUrl line = url;
 				#if QT_VERSION >= 0x050000
 				line.setQuery(q->query(QUrl::FullyDecoded));
 				#endif
@@ -669,7 +765,7 @@ RetrieveYoutubeUrl::Quality RetrieveYoutubeUrl::findResolution(const UrlMap & ur
 	return None;
 }
 
-RetrieveYoutubeUrl::Quality RetrieveYoutubeUrl::findPreferredResolution(const UrlMap & url_map, Resolution res, bool use_dash) {
+RetrieveYoutubeUrl::Quality RetrieveYoutubeUrl::findPreferredResolution(const UrlMap & url_map, Resolution res, bool use_dash, bool use_60fps) {
 	Quality chosen_quality = None;
 
 	QList<Quality> l2160p, l1440p, l1080p, l720p, l480p, l360p, l240p;
@@ -694,12 +790,12 @@ RetrieveYoutubeUrl::Quality RetrieveYoutubeUrl::findPreferredResolution(const Ur
 		l2160p << DASH_VIDEO_WEBM_2160p60hdr;
 		#endif
 
-		#if 0
-		l720p << DASH_VIDEO_720p60 << DASH_VIDEO_WEBM_720p60;
-		l1080p << DASH_VIDEO_1080p60 << DASH_VIDEO_WEBM_1080p60;
-		l1440p << DASH_VIDEO_WEBM_1440p60;
-		l2160p << DASH_VIDEO_WEBM_2160p60;
-		#endif
+		if (use_60fps) {
+			l720p << DASH_VIDEO_720p60 << DASH_VIDEO_WEBM_720p60;
+			l1080p << DASH_VIDEO_1080p60 << DASH_VIDEO_WEBM_1080p60;
+			l1440p << DASH_VIDEO_WEBM_1440p60;
+			l2160p << DASH_VIDEO_WEBM_2160p60;
+		}
 
 		l2160p << DASH_VIDEO_2160p << DASH_VIDEO_2160p2 << DASH_VIDEO_WEBM_2160p << DASH_VIDEO_WEBM_2160p2;
 		l1440p << DASH_VIDEO_1440p << DASH_VIDEO_WEBM_1440p;
