@@ -157,84 +157,84 @@
         <translation>Muat turun</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="501"/>
+        <location filename="../browserwindow.cpp" line="527"/>
         <source>Connection failed</source>
         <translation>Sambungan gagal</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="502"/>
+        <location filename="../browserwindow.cpp" line="528"/>
         <source>The video you requested needs to open a HTTPS connection.</source>
         <translation>Video yang anda pinta perlukan sambungan HTTPS terbuka.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="503"/>
+        <location filename="../browserwindow.cpp" line="529"/>
         <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
         <translation>Malang bagi komponen OpenSSL, diperlukan, tetapi tidak tersedia dalam sistem anda.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="508"/>
+        <location filename="../browserwindow.cpp" line="534"/>
         <source>No video found</source>
         <translation>Tiada video ditemui</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="509"/>
+        <location filename="../browserwindow.cpp" line="535"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
         <translation>Adalah mustahil dapat mencari URL untuk video ini.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="519"/>
-        <location filename="../browserwindow.cpp" line="527"/>
+        <location filename="../browserwindow.cpp" line="545"/>
+        <location filename="../browserwindow.cpp" line="553"/>
         <source>Problems with YouTube</source>
         <translation>Masalah dengan YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="520"/>
-        <location filename="../browserwindow.cpp" line="528"/>
+        <location filename="../browserwindow.cpp" line="546"/>
+        <location filename="../browserwindow.cpp" line="554"/>
         <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
         <translation>Malangnya kerana terdapat perubahan dalam Youtube, video &apos;%1&apos; tidak dapat dimainkan.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="521"/>
+        <location filename="../browserwindow.cpp" line="547"/>
         <source>Do you want to update the YouTube code? This may fix the problem.</source>
         <translation>Anda mahu kemaskini kod Youtube? Ia dapat membaiki masalah.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="529"/>
+        <location filename="../browserwindow.cpp" line="555"/>
         <source>Maybe updating this application could fix the problem.</source>
         <translation>Dengan mengemaskini aplikasi ini dapat membaiki masalah tersebut.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="548"/>
+        <location filename="../browserwindow.cpp" line="574"/>
         <source>About this release</source>
         <translation>Perihal keluaran ini</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="549"/>
+        <location filename="../browserwindow.cpp" line="575"/>
         <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
         <translation>Oleh kerana terdapat perubahan dalam YouTube, SMTube lama tidak dapat berfungsi dengan baik lagi.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="550"/>
+        <location filename="../browserwindow.cpp" line="576"/>
         <source>This is a new version of SMTube, written from scratch.</source>
         <translation>Ini merupakan versi terbaharu SMTube, yang ditulis dari awal.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="551"/>
+        <location filename="../browserwindow.cpp" line="577"/>
         <source>Some functionality is not available yet.</source>
         <translation>Beberapa kefungsian masih belum tersedia lagi.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="553"/>
+        <location filename="../browserwindow.cpp" line="579"/>
         <source>Important:</source>
         <translation>Penting:</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="554"/>
+        <location filename="../browserwindow.cpp" line="580"/>
         <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
         <translation>Jika video VEVO masih gagal dimainkan, sila guna pilihan %1 dalam menu Bantuan.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="555"/>
+        <location filename="../browserwindow.cpp" line="581"/>
         <source>Update the YouTube code</source>
         <translation>Kemaskini kod YouTube</translation>
     </message>
@@ -244,50 +244,6 @@
         <translation>Memuatkan... %1%</translation>
     </message>
 </context>
-<context>
-    <name>CodeDownloader</name>
-    <message>
-        <location filename="../codedownloader.cpp" line="37"/>
-        <source>Downloading...</source>
-        <translation>Memuat turun...</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="58"/>
-        <source>Connecting to %1</source>
-        <translation>Menyambung ke %1</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="126"/>
-        <source>The Youtube code has been updated successfully.</source>
-        <translation>Kod Youtube telah berjaya dikemaskini.</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="127"/>
-        <source>Installed version: %1</source>
-        <translation>Versi dipasang: %1</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="128"/>
-        <source>Success</source>
-        <translation>Berjaya</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <location filename="../codedownloader.cpp" line="138"/>
-        <source>Error</source>
-        <translation>Ralat</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="133"/>
-        <source>An error happened writing %1</source>
-        <translation>Ralat berlaku semasa menulis %1</translation>
-    </message>
-    <message>
-        <location filename="../codedownloader.cpp" line="138"/>
-        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
-        <translation>Ralat berlaku semasa memuat turun fail:&lt;br&gt;%1</translation>
-    </message>
-</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -376,7 +332,7 @@
         <translation>Turun</translation>
     </message>
     <message>
-        <location filename="../configdialog.cpp" line="81"/>
+        <location filename="../configdialog.cpp" line="74"/>
         <source>Default</source>
         <translation>Lalai</translation>
     </message>
@@ -392,50 +348,59 @@
 <context>
     <name>MyWebView</name>
     <message>
-        <location filename="../mywebview.cpp" line="36"/>
-        <source>Open link in a web browser</source>
-        <translation>Buka pautan di dalam pelayar sesawang</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="52"/>
-        <source>Open link in new window</source>
-        <translation>Buka pautan dalam tetingkap baharu</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="75"/>
-        <source>Open audio with</source>
-        <translation>Buka audio dengan</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="99"/>
-        <location filename="../mywebview.cpp" line="124"/>
-        <source>Open with %1</source>
-        <translation>Buka dengan %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="131"/>
-        <source>Open audio with %1</source>
-        <translation>Buka audio dengan %1</translation>
-    </message>
-    <message>
-        <location filename="../mywebview.cpp" line="49"/>
-        <source>Copy link to clipboard</source>
-        <translation>Salin pautan ke papan keratan</translation>
+        <location filename="../mywebview.cpp" line="37"/>
+        <source>Open in &amp;YouTube</source>
+        <translation>Buka dalam &amp;YouTube</translation>
     </message>
     <message>
         <location filename="../mywebview.cpp" line="48"/>
-        <source>Save link...</source>
-        <translation>Simpan pautan...</translation>
+        <source>&amp;Save link...</source>
+        <translation>&amp;Simpan pautan...</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="50"/>
+        <location filename="../mywebview.cpp" line="51"/>
+        <source>Copy &amp;link to clipboard</source>
+        <translation>Salin &amp;pautan ke papan keratan</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="52"/>
         <source>Open link in this window</source>
         <translation>Buka pautan dalam tetingkap ini</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="51"/>
-        <source>Copy text to clipboard</source>
-        <translation>Salin teks ke dalam papan keratan</translation>
+        <location filename="../mywebview.cpp" line="54"/>
+        <source>&amp;Copy text to clipboard</source>
+        <translation>Sa&amp;lin teks ke papan keratan</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="55"/>
+        <source>Open link in &amp;new window</source>
+        <translation>Buka pautan dalam tetingkap &amp;baharu</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="79"/>
+        <source>&amp;Play with</source>
+        <translation>&amp;Main dengan</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="84"/>
+        <source>Play &amp;audio with</source>
+        <translation>Main &amp;audio dengan</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="137"/>
+        <source>&amp;Play with %1</source>
+        <translation>&amp;Main dengan %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="144"/>
+        <source>Play &amp;audio with %1</source>
+        <translation>Main &amp;audio dengan %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="151"/>
+        <source>Play video with a &amp;web browser</source>
+        <translation>Main video dengan pelayan sesa&amp;wang</translation>
     </message>
 </context>
 <context>
